# Developer Advocate

<p class="description">You will build a thriving and connected developer community around our suite of products.</p>

## Details of the Role

- Location: Remote (strong requirement for UTC-8 to UTC+2).
- Type of work: Full-time (contractor or employee [depending on circumstances](https://mui-org.notion.site/Hiring-FAQ-64763b756ae44c37b47b081f98915501#494af1f358794028beb4b7697b5d3102)).
- We're a remote company, we prefer asynchronous communication over meetings.
- We work independently, the rest of us won't know what you're doing day-to-day unless you tell us.

## About the company

MUI started with Material UI, the most successful React implementation of Google's Material Design.
We have gained a large following, thanks to our focus on Material Design fidelity, our obsession with details, on offering a large number of components, our community engagement, and by carefully improving the DX.
Today, countless teams and organizations rely on our open-source libraries to build their design system.

A couple of years ago, we started to expand our suite of products.
We released [MUI X](/x/), a collection of advanced components; [MUI Design kits](/design-kits/), the MUI components available for Figma, Sketch, etc.; and also host [Templates](/templates/), a set of pre-built UI kits.
We've seen rapid growth with all of them (2-3x per year) and we have more to come.
We are building [a low-code platform](https://mui.com/toolpad/) for developers to significantly increase the speed and lower the barrier for creating simple CRUD/dashboard UIs with MUI.

We are a fully distributed team, spread across multiple time zones.
We work mainly asynchronously, relying mostly on written collaboration.
Every contributor has the freedom to define how they work — the rest of us won't know what you're doing day-to-day unless you tell us.
For additional details about the MUI team and culture, you can check our [careers](/careers/) and [about](/about/) pages and also our [public Handbook](https://mui-org.notion.site/Handbook-f086d47e10794d5e839aef9dc67f324b).

## Why we're hiring

In our [last developer survey](/blog/2021-developer-survey-results/#what-else-can-we-do-to-improve-mui-for-you), we learned that we have a long way to go in helping developers to be successful with our technology.
We have underinvested in this area for too long.
Your mission will be to be the voice of the developers of the community inside the company.
We are looking for someone that can contribute to the following outcomes:

- Create momentum in the React community and drive adoption of the library.
- Improve the overall developer experience, resulting in better NPS & CSAT scores, e.g., through educational content.
- Amplify the need of the community so the product direction aims at what people need the most.

Both our open-source community and our premium products are growing fast (x2 YoY).
We need talented people to keep that going!

## About the role

We are looking for a experienced developer to join us as a Developer Advocate to help the developers get familiar with and use MUI most effectively.

### Why this is interesting

Our solution empowers React developers to build awesome applications faster – we see millions of developers on MUI's docs every year, one million a month.

### What you'll do on a day-to-day basis

Depending on the day, you'll:

- **Content**.
  - Produce high quality technical "how-to" content (blogs, webinars, demos, talks) addressing common user needs, latest technology advances, and emerging best practices. Videos might go to [our YouTube channel](https://www.youtube.com/channel/UCUdh2wVTrd7hErLo9Rh0HsQ).
  - Distribute content and leverage pieces to broaden awareness of the MUI brand, via existing connections.
  - Rework the pages of the documentation that are confusing, base on feedback.
- **Community**.
  - Built our developer-focused community.
  - Deliver presentations at meetups, conferences, and other ecosystem events.
  - Create & produce events (podcasts, roundtables, hackathons).
  - Manage the sponsorships of events, newsletters, etc.
  - Help other team members grow at engaging with the community. For instance by encouraging and providing critical feedback on the blog posts they create, or by keeping track of the health of community contributions.
- **Relationship-building**.
  - Create relationships with fellow ecosystem influencers and open-source leaders.
  - Nurture ongoing connections with user group members to build personal relationships and deeply understand their needs, usage, journeys, and barriers to adoption.
- **Technical**.
  - Write code where required to support how-to content, blog posts, and presentations.
  - Create inspiring sample applications, documentation, and tutorials.
  - Give feedback to product management, to influence the product roadmaps based on developers' needs.
  - Follow GitHub issues to understand where developers face frustration and develop strategies to overcome these. This could be suggesting or implementing documentation updates, or proposing or contributing code changes that solve the core issue.

For the right candidate:

- Working with the Leadership to construct and execute on a hiring plan to grow the Developer Experience team.

### Here are a few initiatives you might work on

- Create a learning section in the documentation for hybrid written and video tutorials.
- Own the Algolia search experience, improving the content on the most frequent search queries.
- Take ownership of the company's Twitter account.
- Level up the showcase, cherry-picking the best websites and apps of the community.
- Revamp the blog post infrastructure to empower the rest of the team to create more content.
- Start a monthly newsletter to engage with the community.
- Organize a MUIConf (once we go >50 people)
- Think about creative ways to promote MUI Base, Joy UI, MUI X, MUI X Pro, and new products.

## About you

### Skills you should have

- You are fluent in English (both written and spoken). You'll be the face of MUI in the world, and make everyone in the company proud of the Developer Experience team.
- You are a highly empathic person.
- You are passionate about helping other developers solve problems and have an educational mindset.
- You have some formal or informal experience in teaching: training, tutoring, mentoring, etc.
- Hands-on developer who is comfortable with full-stack development.
- You are passionate about UI development.

### What would be nice if you had, but isn't required

- Experience in building community across some of the following channels: Twitter, YouTube, Twitch, Discord, blogs, meetups, public speaking & events
- Experience working with open-source and/or with the open-source community.
- Experience working with/editing video.
- Experience using MUI.

## Benefits & Compensation

Competitive compensation depending on the profile and location.
We are ready to pay top market rates for a person that can clearly exceed the role's expectations.
You can find the other perks & benefits on the [careers](/careers/#perks-amp-benefits) page.

## How to apply?

[Apply now for this position 📮](https://jobs.ashbyhq.com/MUI/28287eeb-88d2-465f-96d7-e7fd99fabd7d/application?utm_source=ZNRrPGBkqO)
